Top

    10211Origins - Thursday 2
    Columbus, Ohio
    June 9th 2022
    2R+F
    21 players
    Darby Keeney
    https://www.vekn.net/event-calendar/event/10211

    -- 1GW6 + 3 VP in final

    Description: Bruise bleed based around V5 Brujah Barons, New Carthage and Anarch bleed cards. It carries light multi-action, a touch of stealth and just enough bounce that it doesn't have to look left immediately. The titles influence others' political actions, even if I'm not using them myself.

    In the final, I roasted my prey's opening (famous) Malgorzata even though she dropped a Blood of Acid in the first combat.  It was ENTIRELY worth losing a 3-cap who had already done the Illegalism/unlock/Manifesto trick.  I ate Mal a turn or two later, just to be sure she didn't make beads.

    Crypt (12 cards, min=18, max=30, avg=6.17)
    ------------------------------------------
    2x Theo Bell	       8  CEL POT PRE aus dom	      Brujah:6
    2x Aline Gädeke	       7  POT PRE cel	       baron  Brujah:6
    2x Valeriya Zinovieva  7  POT cel pre pro      baron  Brujah:6
    2x Leumeah	       6  PRE cel for pot      baron  Brujah:6
    1x Atiena	       6  CEL obf pot pre      baron  Brujah:6
    1x Brandon Grime       5  CEL pot pre tha	      Brujah:6
    1x Elen Kamjian	       4  CEL POT		      Brujah:6
    1x Ariane	       3  cel pot pre		      Brujah:5

    The original build used more superior Presence minions but no Theo and some Enchant Kindred. I didn't like the pace at which it played and adjusted for more immediate offense.  I finally broke down and added Theo right before Origins - he sheds red cards and I get a second +1 strength minion.
    Every one of those revisions made the deck better and this iteration feels extremely solid.

    Library (90 cards)
    -- I think there might be a 78 card version that's even more consistent.  And no, you don't need Ashur Tablets.
    Master (18; 5 trifle)
    2x Blood Doll
    1x Carfax Abbey
    1x Club Illusion -- dangerous play in today's meta
    2x Dreams of the Sphinx
    1x Fame
    1x Garibaldi-Meucci Museum -- this card just keeps getting better.
    1x Giant's Blood
    2x New Carthage -- this version could probably drop to 1 copy
    1x Powerbase: Los Angeles -- more unlocked Barons at the end of my turn.
    5x Villein -- this could be 6 copies and the deck wouldn't suffer.
    1x Warzone Hunting Ground

    Action (21)
    1x Fee Stake: New York -- should probably change to LA just for thematic reasons
    9x Illegalism -- combat minions that bleed, then unlock and fight are pretty good.
    10x Line Brawl -- see above. The occasional pool steal can screw up other players' math.
    1x Open War -- almost overkill with Theo and Line Brawls.

    Equipment (2)
    2x Anarch Manifesto, An -- slotted during last revision, these things are gold in the mid game (get them AFTER you unlock from Illegialism, don't defer bleed actions to get it)

    Action Modifier (8)
    6x Power of One -- I didn't bother with the unlimited [pot] line with a Monkey Wrench, it's better to just have these for stealth on bleeds.
    2x Zephyr -- don't laugh...even at inferior it is an unlocked bouncer (or a multirushing Theo at superior).

    Reaction (5)
    5x Bait and Switch -- this card is shaking up the meta around here.

    Combat (36)
    2x Bollix -- kind of iffy, but I like having extra maneuvers and presses hanging around.
    2x Disarm -- never played on a minion I wasn't dunking anyway, this might be overkill.
    3x Diversion -- only OK in this deck since Dust Up often eats the additional strike.
    10x Dust Up -- underrated as a dual use combat tool.
    4x Immortal Grapple -- because Earth Meld decks need to be killed with fire.
    2x Pulled Fangs -- sometimes minions just need to stay down
    5x Target Vitals -- slotted in yet another [pot] deck....this card is poorly designed.
    4x Taste of Vitae
    4x Thrown Gate -- a token nod to "screw your Sniper Rifle" with backup defensive value